Preserves class when grouping decorated.
# S3 method for decorated
group_by(.data, ..., add = FALSE, .drop = group_by_drop_default(.data))A data frame, data frame extension (e.g. a tibble), or a lazy data frame (e.g. from dbplyr or dtplyr). See Methods, below, for more details.
In group_by(), variables or computations to group by.
In ungroup(), variables to remove from the grouping.
When FALSE, the default, group_by() will
override existing groups. To add to the existing groups, use
.add = TRUE.
This argument was previously called add, but that prevented
creating a new grouping variable called add, and conflicts with
our naming conventions.
When .drop = TRUE, empty groups are dropped. See group_by_drop_default() for
what the default value is for this argument.
Other dplyr:
anti_join.decorated(),
arrange.decorated(),
as_decorated(),
filter.decorated(),
full_join.decorated(),
inner_join.decorated(),
left_join.decorated(),
mutate.decorated(),
right_join.decorated(),
select.decorated(),
semi_join.decorated(),
slice.decorated(),
summarise.decorated(),
summarize.decorated()